@@ -5,10 +5,9 @@ use 5.010;
 use utf8;
 package App::AppSpec;
 use Term::ANSIColor;
-use YAML::PP;
 use File::Basename qw/ dirname /;
 
-our $VERSION = '0.003_002'; # TRIAL VERSION
+our $VERSION = '0.002'; # VERSION
 
 use base 'App::Spec::Run::Cmd';
 
@@ -41,13 +40,8 @@ sub generate_pod {
     my $parameters = $run->parameters;
 
     my $spec = $self->_read_spec($run);
-
-    require App::Spec::Pod;
-    my $generator = App::Spec::Pod->new(
-        spec => $spec,
+    my $pod = $spec->generate_pod(
     );
-    my $pod = $generator->generate;
-
     say $pod;
 }
 
@@ -55,13 +49,14 @@ sub cmd_validate {
     my ($self, $run) = @_;
     my $options = $run->options;
     my $parameters = $run->parameters;
+    my $color = $self->colorize;
 
     my @errors;
     require App::AppSpec::Schema::Validator;
     my $validator = App::AppSpec::Schema::Validator->new;
     my $spec_file = $parameters->{spec_file};
     if (ref $spec_file eq 'SCALAR') {
-        my $spec = YAML::PP::Load($$spec_file);
+        my $spec = YAML::XS::Load($$spec_file);
         @errors = $validator->validate_spec($spec);
     }
     else {
@@ -70,10 +65,14 @@ sub cmd_validate {
     binmode STDOUT, ":encoding(utf-8)";
     if (@errors) {
         print $validator->format_errors(\@errors);
-        say $run->colored(out => red => "Not valid!");
+        $color and print color 'red';
+        say "Not valid!";
+        $color and print color 'reset';
     }
     else {
-        say $run->colored(out => [qw/ bold green /] => "Validated ✓");
+        $color and print color 'bold green';
+        say "Validated ✓";
+        $color and print color 'reset';
     }
 }
 
@@ -110,12 +109,10 @@ class: $class
 title: 'app title'
 description: 'app description'
 options:
-- name: some-flag
-  type: flag
-  summary: option summary
-- spec: other-option=s --another option
+- name: "some-option"
+  type: "flag"
+  summary: "option summary"
 EOM
-    my $subname = $options->{"with-subcommands"} ? "mycommand" : "execute";
     my $module = <<"EOM";
 package $class;
 use strict;
@@ -123,7 +120,7 @@ use warnings;
 use feature qw/ say /;
 use base 'App::Spec::Run::Cmd';
 
-sub $subname \{
+sub mycommand \{
     my (\$self, \$run) = \@_;
     my \$options = \$run->options;
     my \$parameters = \$run->parameters;
@@ -169,7 +166,7 @@ EOM
     File::Path::make_path("$dist/bin");
     File::Path::make_path(dirname $module_path);
     my $specfile = "$dist/share/$name-spec.yaml";
-    say "Writing spec to $specfile";
+    say "Writig spec to $specfile";
     open my $fh, ">", $specfile or die $!;
     print $fh $spec;
     close $fh;
@@ -207,11 +204,6 @@ completion or pod from it.
 
 =back
 
-=head1 LICENSE
-
-This library is free software and may be distributed under the same terms
-as perl itself.
-
 =cut
 
 1;
